@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Tables
-Version : 1.0.1
+Version : 1.0.3
 Author  : Stefano Covino
-Date    : 11/02/2013
+Date    : 01/11/2015
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -15,9 +15,11 @@ Remarks :
 
 History : (08/11/2010) First version.
         : (11/02/2013) CleanStr and SkyStr added.
+        : (27/10/2015) ReadCleanedTextFile added.
+        : (01/11/2015) HTML added.
 """
 
 
 
-__all__ = ['CleanStr', 'FindObjects', 'SkyStr']
+__all__ = ['CleanStr', 'FindObjects', 'HTML', 'ReadCleanedTextFile', 'SkyStr']
 
