@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.55
+Version : 1.3.19
 Author  : Stefano Covino
-Date    : 22/12/2014
+Date    : 01/10/2020
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -129,21 +129,81 @@ History : (28/09/2010) First named version.
         : (19/11/2014) V. 3.12.2b3.
         : (09/12/2014) V. 3.12.2b4.
         : (16/12/2014) V. 3.12.2b5.
-        : (22/12/2014) V. 3.12.2.
+        : (22/12/2014) V. 3.12.2 and 3.12.3b1.
+        : (12/01/2015) V. 3.12.3b2.
+        : (20/01/2015) V. 3.12.3b3.
+        : (01/04/2015) V. 3.12.3b4.
+        : (22/05/2015) V. 3.12.3b5.
+        : (24/07/2015) V. 4.0.0.b1.
+        : (29/07/2015) V. 4.0.0.
+        : (31/07/2015) V. 4.0.1b1.
+        : (27/10/2015) V. 4.0.1b2.
+        : (01/11/2015) V. 4.0.1b3.
+        : (03/11/2015) V. 4.0.1.
+        : (05/11/2015) V. 4.0.2b1.
+        : (08/11/2015) V. 4.0.2b2.
+        : (09/11/2015) V. 4.0.2.
+        : (10/11/2015) V. 4.1.0b1.
+        : (11/12/2015) V. 4.1.0b2.
+        : (27/01/2016) V. 4.1.0b3.
+        : (14/02/2016) V. 4.1.0b4.
+        : (17/02/2016) V. 4.1.0b5 and V. 4.1.0.
+        : (02/04/2016) V. 4.1.1.
+        : (13/06/2016) V. 4.1.2.
+        : (16/06/2016) V. 4.1.3b1.
+        : (07/07/2016) V. 4.1.3b2.
+        : (13/07/2016) V. 4.1.3b3.
+        : (19/10/2016) V. 4.1.3.
+        : (02/11/2016) V. 4.1.4b1.
+        : (05/12/2016) V. 4.1.4b2.
+        : (04/01/2017) V. 4.1.4b3 and 4.1.4.
+        : (12/01/2017) V. 4.1.5b1.
+        : (08/02/2017) V. 4.1.5b2.
+        : (14/02/2017) V. 4.1.5b3.
+        : (16/02/2017) V. 4.1.5b4.
+        : (17/02/2017) V. 4.1.5b5.
+        : (21/02/2017) V. 4.2.0.
+        : (14/03/2017) V. 4.2.1b1 and 4.2.1.
+        : (19/04/2017) V. 4.2.2.
+        : (28/04/2017) V. 4.2.3.
+        : (29/04/2017) V. 4.2.4.
+        : (09/05/2017) V. 4.2.5.
+        : (16/05/2017) V. 4.2.6.
+        : (18/05/2017) V. 4.2.7.
+        : (26/05/2017) V. 4.2.8.
+        : (03/07/2017) V. 4.2.9.
+        : (22/08/2017) V. 4.2.10.
+        : (18/09/2017) V. 4.2.11.
+        : (18/10/2017) V. 4.2.12.
+        : (19/01/2018) V. 4.3.13.
+        : (11/07/2018) V. 4.3.14.
+        : (20/08/2018) V. 4.3.15.
+        : (17/01/2019) V. 4.3.16.
+        : (25/02/2019) V. 4.3.17.
+        : (28/04/2019) V. 4.3.18.
+        : (13/05/2019) V. 4.4.0.
+        : (20/05/2019) V. 4.4.1.
+        : (21/08/2019) V. 4.4.2.
+        : (04/10/2019) V. 4.4.3.
+        : (29/01/2020) V. 4.5.0.
+        : (23/04/2020) V. 4.5.1.
+        : (12/08/2020) V. 4.6.0.
+        : (01/10/2020) V. 4.6.1.
 """
 
 
 
 # import
-import pkg_resources
+#import pkg_resources
 
 
-__all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhotometry', 
-           'SRPPipelines', 'SRPPolarimetry', 'SRPREM', 'SRPSky', 'SRPSpectroscopy', 
-           'SRPStatistics', 'SRPSystem', 'SRPTables', 'SRPTime', 'SRPTNG']
+__all__ = ['SRPDatabases', 'SRPCatalogue', 'SRPMath', 'SRPNet',
+           'SRPPipelines', 'SRPPlot', 'SRPPolarimetry', 'SRPREM', 
+           'SRPSky', 'SRPSpectroscopy', 'SRPSystem', 'SRPTables',
+           'SRPTime', 'SRPTNG']
 
 
 # Version
-__version__ = '3.12.2'
+__version__ = '4.6.2'
 
-#
\ No newline at end of file
+#
